@@ -7,7 +7,7 @@ use overload
     '""' => '_as_string',
     'eq' => '_as_string';
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 =head1 NAME
 
@@ -90,6 +90,14 @@ sub new {
         reformatted => undef,
     }, $class;
     return $self;
+}
+
+sub from {
+    my ($class, %parameters) = @_;
+    
+
+
+
 }
 
 =head2 postcode_string ( )
@@ -136,6 +144,7 @@ The first call to a location-related method of Geo::Postcode will cause the loca
 
 The accuracy of the information returned by location methods depends on the resolution of the location data file: see the POD for Geo::Postcode::Location for how to supply your own dataset instead of using the crude set that comes with this module.
 
+
 =head2 location_class ()
 
 Returns the full name of the class that should be called to get a location object.
